@@ -4,11 +4,17 @@ use strict;
 use warnings;
 
 use Mojolicious::Lite;
+use Data::Dumper;
+use IO::Socket::SSL;
+
+# work around for example only (don't do this in PROD code)
+IO::Socket::SSL::set_defaults(
+  SSL_verify_mode => IO::Socket::SSL::SSL_VERIFY_NONE,
+);
 
 my $host = $ENV{HOST} // '127.0.0.1';
 
 plugin 'OAuth2', {
-  fix_get_token => 1,
   overly_attached_social_network => {
      authorize_url => "https://$host:3000/oauth/authorize?response_type=code",
      token_url     => "https://$host:3000/oauth/access_token",
@@ -18,10 +24,13 @@ plugin 'OAuth2', {
   },
 };
 
-get '/' => sub {
-  my ( $c ) = @_;
-  $c->render( 'index' );
-};
+app->helper(
+  delay => sub {
+    my $c  = shift;
+    my $tx = $c->render_later->tx;
+    Mojo::IOLoop->delay(@_)->catch(sub { $c->helpers->reply->exception(pop) and undef $tx })->wait;
+  }
+);
 
 get '/auth' => sub {
   my $self = shift;
@@ -37,13 +46,18 @@ get '/auth' => sub {
       },
       sub {
         my( $delay,$error,$data ) = @_;
-		return $self->render( error => $error ) if ! $data->{access_token};
+        return $self->render( error => $error ) if ! $data->{access_token};
         return $self->render( json => $data );
       },
     );
   }
 };
 
+get '/' => sub {
+  my ( $c ) = @_;
+  $c->render( 'index' );
+};
+
 app->start;
 
 # vim: ts=2:sw=2:et
