@@ -4,6 +4,8 @@ package Net::OAuth2::AuthorizationServer::ImplicitGrant;
 
 Net::OAuth2::AuthorizationServer::ImplicitGrant - OAuth2 Resource Owner Implicit Grant
 
+You "SHOULD NOT" use this grant type (see L<https://tools.ietf.org/html/draft-ietf-oauth-security-topics-15>)
+
 =head1 SYNOPSIS
 
   my $Grant = Net::OAuth2::AuthorizationServer::ImplicitGrant->new(
@@ -44,6 +46,7 @@ Net::OAuth2::AuthorizationServer::ImplicitGrant - OAuth2 Resource Owner Implicit
     scopes          => $scopes_ref,
     redirect_uri    => $redirect_uri,
     user_id         => $user_id,      # optional
+	jwt_claims_cb   => sub { ... },   # optional, see jwt_claims_cb in Manual
   );
 
   # store access token
