@@ -103,7 +103,6 @@ sub run_tests {
 	ok( ! $error,'has no error' );
 
 	foreach my $t (
-		[ { scopes => [ qw/ eat sleep drink / ] },'access_denied','disallowed scopes' ],
 		[ { scopes => [ qw/ eat sleep yawn / ] },'invalid_scope','invalid scopes' ],
 		[ { client_id => 'another_client' },'unauthorized_client','invalid client' ],
 	) {
@@ -113,6 +112,16 @@ sub run_tests {
 		is( $error,$t->[1],'has error' );
 	}
 
+    foreach my $t (
+		[ { scopes => [ qw/ eat sleep drink / ] },[ qw / eat sleep / ],'disallowed scopes' ],
+    ) {
+        my $scopes;
+        ( $res, $error, $scopes ) = $Grant->verify_client( %valid_client,%{ $t->[0] } );
+
+        ok ( $res, '->verify_client, ' . $t->[2] );
+        cmp_deeply( $scopes, $t->[1], 'has reduced scopes' );
+    }
+
 	note( "store_access_token" );
 
 	ok( my $access_token = $Grant->token(
